@@ -152,7 +152,7 @@ impl PublishStep {
         super::confirm("Publish", &selected_pkgs, self.no_confirm, dry_run)?;
 
         // STEP 3: cargo publish
-        publish(&selected_pkgs, dry_run, &ws_config.unstable)?;
+        publish(&selected_pkgs, dry_run)?;
 
         super::finish(failed, dry_run)
     }
@@ -169,28 +169,24 @@ impl PublishStep {
     }
 }
 
-pub fn publish(
-    pkgs: &[plan::PackageRelease],
-    dry_run: bool,
-    unstable: &crate::config::Unstable,
-) -> Result<(), CliError> {
+pub fn publish(pkgs: &[plan::PackageRelease], dry_run: bool) -> Result<(), CliError> {
     if pkgs.is_empty() {
         Ok(())
-    } else if unstable.workspace_publish() {
+    } else {
         let first_pkg = pkgs.first().unwrap();
         let registry = first_pkg.config.registry();
         let target = first_pkg.config.target.as_deref();
-        if pkgs
-            .iter()
-            .all(|p| p.config.registry() == registry && p.config.target.as_deref() == target)
+        let publish_grace_sleep = publish_grace_sleep();
+        if publish_grace_sleep.is_none()
+            && pkgs
+                .iter()
+                .all(|p| p.config.registry() == registry && p.config.target.as_deref() == target)
         {
             let manifest_path = &first_pkg.manifest_path;
             workspace_publish(manifest_path, pkgs, registry, target, dry_run)
         } else {
-            serial_publish(pkgs, dry_run)
+            serial_publish(pkgs, publish_grace_sleep, dry_run)
         }
-    } else {
-        serial_publish(pkgs, dry_run)
     }
 }
 
@@ -228,27 +224,14 @@ fn workspace_publish(
         return Err(101.into());
     }
 
-    // HACK: This is a fallback in case users can't or don't want to rely on cargo waiting for
-    // them
-    if !dry_run {
-        let publish_grace_sleep = std::env::var("PUBLISH_GRACE_SLEEP")
-            .unwrap_or_else(|_| Default::default())
-            .parse()
-            .unwrap_or(0);
-        if 0 < publish_grace_sleep {
-            log::debug!(
-                "waiting an additional {} seconds for {} to update its indices...",
-                publish_grace_sleep,
-                registry.unwrap_or("crates.io")
-            );
-            std::thread::sleep(std::time::Duration::from_secs(publish_grace_sleep));
-        }
-    }
-
     Ok(())
 }
 
-fn serial_publish(pkgs: &[plan::PackageRelease], dry_run: bool) -> Result<(), CliError> {
+fn serial_publish(
+    pkgs: &[plan::PackageRelease],
+    publish_grace_sleep: Option<u64>,
+    dry_run: bool,
+) -> Result<(), CliError> {
     for pkg in pkgs {
         if !pkg.config.publish() {
             continue;
@@ -287,21 +270,27 @@ fn serial_publish(pkgs: &[plan::PackageRelease], dry_run: bool) -> Result<(), Cl
 
         // HACK: This is a fallback in case users can't or don't want to rely on cargo waiting for
         // them
-        if !dry_run {
-            let publish_grace_sleep = std::env::var("PUBLISH_GRACE_SLEEP")
-                .unwrap_or_else(|_| Default::default())
-                .parse()
-                .unwrap_or(0);
-            if 0 < publish_grace_sleep {
-                log::debug!(
-                    "waiting an additional {} seconds for {} to update its indices...",
-                    publish_grace_sleep,
-                    pkg.config.registry().unwrap_or("crates.io")
-                );
-                std::thread::sleep(std::time::Duration::from_secs(publish_grace_sleep));
-            }
+        if !dry_run && let Some(publish_grace_sleep) = publish_grace_sleep {
+            log::debug!(
+                "waiting an additional {} seconds for {} to update its indices...",
+                publish_grace_sleep,
+                pkg.config.registry().unwrap_or("crates.io")
+            );
+            std::thread::sleep(std::time::Duration::from_secs(publish_grace_sleep));
         }
     }
 
     Ok(())
 }
+
+fn publish_grace_sleep() -> Option<u64> {
+    let publish_grace_sleep = std::env::var("PUBLISH_GRACE_SLEEP")
+        .unwrap_or_else(|_| Default::default())
+        .parse()
+        .unwrap_or(0);
+    if publish_grace_sleep == 0 {
+        None
+    } else {
+        Some(publish_grace_sleep)
+    }
+}
